@@ -2,10 +2,10 @@
 test_that("error outside of test_that()", {
   withr::local_envvar(TESTTHAT_PARALLEL = "TRUE")
   err <- tryCatch(
-    suppressMessages(testthat::test_local(
+    capture.output(suppressMessages(testthat::test_local(
       test_path("test-parallel", "outside"),
-      reporter = "silent"
-    )),
+      reporter = "summary"
+    ))),
     error = function(e) e
   )
 
