@@ -20,7 +20,7 @@ test_that("runs all tests and records output", {
 
 test_that("complains if no files", {
   withr::local_envvar(TESTTHAT_PARALLEL = "FALSE")
-  path <- tempfile()
+  path <- withr::local_tempfile()
   dir.create(path)
 
   expect_error(test_dir(path), "test files")
@@ -96,5 +96,5 @@ test_that("can configure `load_all()` (#1636)", {
 })
 
 test_that("helpers are included in the testing environment", {
-  expect_true("rlang_version" %in% names(the$testing_env))
+  expect_true("abcdefghi" %in% names(the$testing_env))
 })
